from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x08\x00\x55\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x8f\x08\x00\x00\x00\x00\x00\x18\xab\x04\x05\x25\x34\x09\xeb\xb0\xc6\xa9\x65\x68\x0c\xf5\x50\x9e\x00\x00\x00\x00\x00\x00\x00\x00\xdc\x92\x10\x27\x00\xd6\xf8\x76\xe7\x62\x6a\x4a\xa3\x68\xd0\x6e\xdf\x4e\xff\xd2\xa9\xc4\x57\x6d\x3b\x22\xc7\xb8\xa8\x59\x8f\x46\xcd\xd9\x9a\x86\xf3\x88\xdc\x30\xaa\x3b\x43\xdb\x87\xf6\x89\x23\xfd\x6f\xe9\x2d\x9c\xbc\x89\x53\x64\x48\x51\x9d\x48\xfb\xde\xc2\xd0\xe5\xf6\x56\x73\x7e\x7b\xbe\x1f\xce\x1d\x58\x64\x8a\x4c\x2c\x61\xfb\x47\x8e\xea\x00\xf4\x72\x78\x8c\x03\xf9\x09\x63\x7d\x35\xb8\x44\xb4\xfa\x5b\x5b\x3b\x7c\xec\x5c\x68\xad\x6a\x40\x6c\x83\x78\x92\x49\xd5\xcd\xaf\x18\x89\x88\x45\xd2\xba\x6d\x4f\x21\xca\x40\x30\xb2\xad\xf2\x40\x00\x48\xac\xd3\xd2\xf5\x3b\x77\xf0\xc5\x8f\x5b\x72\x7b\x64\x43\x7c\xb6\x25\x4f\xb0\xdf\x63\xb5\xf5\x0f\xd9\xaf\x67\xfa\xbc\xd1\xb1\xff\x74\xb4\x04\x0d\x56\x3a\x99\x47\xa1\x6a\x67\xb1\xa9\xf9\x85\x50\xe5\x0e\x46\x89\x90\xa9\xdf\x33\xdc\xd7\x91\x3f\x72\xaf\x82\x39\x28\x44\xbf\x06\xc3\x26\x72\xdc\x00\x3f\xd8\xb9\x74\x50\x55\x28\xdb\x9e\x7e\x23\x9d\x44\x9f\x56\x58\xc3\x18\xd3\x63\x64\x36\x3d\xfc\x0a\x91\xf4\xf1\xa9\xb6\xcf\xe8\x33\xab\x5d\xa5\x6a\x25\x1d\x5e\xf4\x89\x48\x76\xfe\x81\x87\x1f\x6b\x68\x75\x42\xa6\x57\xf1\x29\xb4\x40\x2e\x91\x08\xeb\x8e\xa9\xe2\x98\xee\x05\x10\xb0\x82\x5b\x86\x6e\x28\x5d\xe1\xda\xca\x58\x75\xcc\xbc\x34\xb1\x8f\x3b\x4f\x52\x1e\x6e\xdc\x90\xad\xe0\xac\x9a\x68\xb2\xcb\x3f\xaa\xf0\x71\x1f\x41\x78\x33\xb2\x10\x5b\xb6\x8a\xa2\x2a\xe3\x89\x63\x4e\x76\x7b\xd5\x02\x0d\xcf\x7a\xe7\xd3\x90\xcc\x54\xfa\x01\x7e\x1f\x82\xae\x5e\xaf\xbf\xe1\xb7\xad\x73\x72\x37\x0a\xbd\x90\x94\xfd\x80\x24\xcb\xcf\xab\xfb\x7f\xd4\x62\x43\x31\xc7\x33\xb6\x37\x0a\x2f\x77\x2c\x94\xea\xc9\x23\xa7\x37\xf6\xfe\x80\x9e\x7e\xc9\x5b\x0a\x8a\xb9\x00\x25\x65\x4f\xd5\xbd\xea\x0e\x30\x6f\x66\x61\x11\x8d\x30\x9f\x08\x80\xb0\x8d\x83\xed\x0d\xa1\x1e\x78\x3c\x0c\x7d\x36\x9b\x06\xf5\x66\xc3\x43\x09\x69\xfd\x6e\x83\x6f\x48\x06\x8e\xb2\xda\xaa\xf5\x2f\xd8\x85\xf7\x2e\x30\x11\xbc\xe6\x31\xe1\xcc\xe9\xe3\x62\x9e\xde\x3a\x43\x13\xdd\xb7\xdd\x45\x5a\x85\x59\x92\xbc\x0c\xa3\xce\xc6\x66\x90\xd7\xa3\xce\x95\x63\x23\x8a\xfb\x71\xc5\x14\xcb\x05\x78\xdd\xaf\xff\x24\x9d\xfb\xe5\xf9\xca\x55\x61\x10\x54\x24\x57\x05\xd7\xbe\x60\x70\x4c\x1c\xb8\x16\x32\xba\xae\xfa\x32\x2f\x03\x79\xe4\xbe\xba\xd2\x20\x53\xe3\xb7\xdc\x49\xc5\xf4\x42\xa0\x68\x7f\xb8\xca\xa0\x63\x66\x5e\x86\xde\x3b\xf8\x0c\x62\x07\xce\xd8\x8c\xe9\xcb\x69\x69\x34\xf9\x49\xf2\x84\x13\x8c\x0e\x21\x41\x95\x8e\xb1\xe1\xa4\xdc\x4d\x5f\x56\x4d\xa3\x97\xdb\x78\x47\x60\x37\xf1\x8d\x28\x16\xec\x31\xdb\xe1\x70\x5a\x8e\xee\x44\x7c\xb9\x41\xd4\x79\xb3\xaf\xc2\x61\x13\xd6\xb6\x0a\x98\xce\x1d\x17\x9e\x00\x3a\x12\xdf\x70\x4c\x1a\xc4\x81\xda\xe2\xee\x95\x7d\x1a\xd3\xe9\xe8\x7d\xdb\xae\x3d\x6c\xcc\x2f\xad\xd0\x85\x27\xe6\x2d\xcd\xcf\x93\x2e\x87\x2b\xcc\x06\x9a\x60\x30\x94\x69\x7d\xce\xa5\x74\x8f\x68\xec\xa8\x64\x25\xeb\xc0\x98\xea\xb7\xf6\x3c\x7a\x73\x79\xd8\x0d\x87\xfa\xd6\x01\x40\x8b\x9c\xd8\xbd\x95\x5c\x85\x2d\xbe\x3a\xc6\x3f\x74\x34\x91\xda\x0c\xc0\x98\xca\x0c\x1d\x89\xca\xcd\x01\x11\x3b\x64\xb5\x0e\xae\x1f\xec\x87\xc6\x9c\x51\xbb\x5c\x5e\x1b\x3c\x78\xda\x1d\xda\xdd\x8b\x2b\x06\x73\x3f\x67\x67\xd0\xd1\x81\x6a\x11\x8a\x0c\xa5\xfb\xa8\xe5\xeb\x5a\x29\x3f\x2f\x6b\xad\xe2\x91\x46\xa4\xe9\x0b\x59\xb4\x06\x56\xe6\xa1\x2e\x07\xd3\x47\xef\xf2\xe2\xf3\x0e\x56\x6c\xa4\x80\x91\x6a\x2d\x2a\xa9\xd2\xe7\x6b\x6c\x0c\x8e\x8a\xed\xc9\x9f\x9c\xbc\xe3\x40\xbb\xab\x9d\x71\xa2\x39\x59\xf7\x7d\xdf\x70\x74\xe9\x99\x7f\xaa\xcf\x45\x2d\x43\x59\xb1\x75\x89\xed\x7c\x54\x10\x87\xd3\x76\x11\xf4\x5e\x13\xee\x4a\xde\xcc\x40\x19\x1c\xc3\x8f\x51\x51\x2a\xd3\x14\x35\x74\xe1\xc4\x8a\xc8\xc6\x01\x54\xc5\x1c\xee\xe8\xfe\x4a\xd6\xad\x62\x4a\x12\xf7\x54\xbd\x33\xe5\xbd\x01\xda\x9d\xd3\x23\x21\x3e\xe4\x09\x19\x61\x71\xb2\xc0\x16\xa3\x18\x56\xcc\x2f\xc7\xa6\x96\x17\xea\x73\x44\x23\x92\xdd\xae\xa8\xba\xa8\xc1\xca\x1a\xcd\x81\x2e\x20\x40\x38\xb2\x52\x80\x60\x1b\x77\xda\xe2\xbb\x1c\x07\xbf\xa2\xa0\x53\xcd\x01\x17\x47\xf4\xd3\x0d\x31\x8b\x8c\x8a\xc7\xb3\xbf\xb6\x5b\xa8\x84\xd4\xda\x04\x6d\x92\x07\xa7\xb9\x6f\xaf\x38\xc2\xaa\x76\x72\xe0\x06\x35\xcf\xdd\xdf\x52\x6a\x65\x58\x3e\xb1\x20\x6a\xf6\xbb\x62\x95\xe0\x3e\x46\x96\xea\x9e\x54\xd3\x08\xc2\xf4\x5f\x8a\x5c\x13\xfb\x78\x65\x02\x98\x3a\x8b\x41\xeb\x10\x59\x79\xed\x79\x8c\xc0\x1f\xa9\x50\xc6\x65\xa4\x2a\x03\x93\x6b\x45\xaa\x5c\x15\x69\x1c\xfd\x8a\xec\x69\x98\x44\x0d\x2e\x2b\x87\x5e\x54\xa6\xd0\x1e\xdb\x99\x7d\xdb\xf2\x00\xe7\x98\xf2\x94\x02\xf2\x58\x25\xec\x01\xe7\x8c\x75\xde\x8b\x38\x99\x9f\x06\xdb\x9f\x8d\x17\x28\xb4\x98\x2d\x3e\x0c\x49\xc6\xe0\xa5\x4e\x4c\xda\x73\x13\x43\x09\xe2\xdf\xba\xa0\x6d\xc7\x2f\x05\x24\xd8\x48\xe1\x3c\xfd\xb3\xf4\x17\x3c\x4f\x5c\x0c\x72\x7e\x50\x45\xb6\xfc\x76\x4c\x5d\x93\x06\x48\x28\x95\x60\xfe\xcf\xf9\xc8\x8d\x65\x90\x47\x78\xa9\x9c\xe1\xde\x99\x0d\xcc\xd7\x85\x10\xd4\xbf\xb7\x98\xba\x10\xee\xae\x26\x81\xaf\x7b\x47\xf1\xda\xce\x18\xa0\x2a\xb3\x56\x32\xaa\x13\x30\x57\x24\x79\x6f\x50\x81\x7a\x02\x1f\x38\x8a\x3a\x5e\x8e\xde\x72\x83\xab\xd2\x1f\x12\x06\x36\x78\x95\xa9\x7a\xdc\xa3\x33\x8e\x30\xf4\x85\xb6\xfa\xf1\x6d\xaa\x16\x60\x32\x15\x55\xaf\x85\x77\xf9\x82\xf7\xef\xc3\x6e\x6d\xea\x23\x15\x54\x0f\x14\xf5\xba\x82\x44\x7f\xd7\x43\xf6\x57\x4d\xfd\xe6\x1b\x22\xd5\xba\x5b\xde\xd4\xf8\x82\xc3\x70\xe1\xa8\x92\xe1\x1e\xb5\x36\x82\x67\x62\xbc\x73\x9c\xd6\x9b\xd4\x4b\x5b\x8d\xe9\x1d\xa4\x5b\xf3\xfd\x47\x71\x04\x25\x13\xe9\xe6\x98\x33\x2b\x50\xf8\x04\xbe\x80\x55\x3e\xff\xce\x5d\xb1\x94\x84\xb6\xf3\x23\xf3\x0c\x48\x19\x2f\x5e\x4c\x11\xa5\x2b\x73\xaa\x1b\x35\x47\x68\x1c\xb1\xb8\x03\x8d\xcd\xc0\x3b\xb0\xda\xd0\xd5\x53\x39\x5f\x6b\x50\xb5\x72\x59\x2c\xa2\x7b\xda\xb4\xee\xb7\x27\x11\xe2\x77\xa7\xb1\xbe\x5c\x6d\xd0\x1c\xe7\xbb\x7d\x0e\x18\x60\xc2\x7c\x67\x16\x0d\xcd\xd3\xdd\xb9\xa0\xe3\x8d\x18\xbd\x53\xdb\xe4\x2b\xf5\x4b\xae\xcf\x9a\xa6\x19\x80\x1a\x6e\x46\xd5\x22\xff\xf9\xd3\x2a\x64\xd2\x4f\xd9\x43\x77\x50\x55\xc1\xf7\xc5\x97\x04\x60\xd3\xfb\x01\xcb\xd5\x0f\x35\xd6\x5f\x9f\x39\x7e\xc4\xbd\xa3\xf3\xb5\x46\x2b\x2e\xa5\x1c\x81\x53\x21\x5a\x59\x6d\x16\x3f\x60\x9d\x11\xdb\x1e\xe0\xcc\x94\x79\xac\xce\xf6\x01\x72\x25\x46\x0f\x18\xf2\x38\xe1\x63\xf5\x6e\xc0\x65\xa6\xfe\x67\xad\x14\xf9\xb4\xb4\xb7\x9d\x66\xd0\x92\xa6\x2d\xb9\x37\x85\x3e\x7f\x5f\x9e\xea\x29\x98\x39\x7a\x07\x00\xaf\x32\xf9\xb9\x89\xaa\x40\x8f\x1c\x1b\xc4\x8e\xd0\x17\x7b\x94\x48\x7f\xd5\x8b\xd7\x71\x5d\x1b\x90\x32\xcf\x39\x0b\x34\xf9\xdf\x3c\xad\x44\x8e\xe8\x29\x5c\x7c\xd7\x1c\x10\x7b\xdc\x03\xc2\x25\xae\x40\xf1\xe8\xad\x07\x18\x77\x0f\x68\xd2\xc1\xe2\x4c\xc8\x74\x1a\x86\x18\x80\xe5\x54\x92\x10\x8b\x56\x57\x86\x2c\x1a\x93\x6a\x35\xae\x99\xf2\x3c\x73\x62\xcd\x3b\x92\x92\x48\x4c\xb1\x83\xd7\x65\x80\x47\x50\x3c\x8b\x90\xa3\xd6\xd4\xca\x03\xc1\xe6\xfe\x75\x36\x9a\xd3\x01\xb5\xce\xe0\xfb\x00\xad\x66\x54\xbd\x51\xd1\x3f\x3c\xea\xce\xc3\xf8\x36\x43\x95\x87\x0e\xc2\xa3\x22\x0e\x02\xc6\x06\x1d\x32\xba\x2b\xb9\x0c\xca\x6e\x7e\xba\x9a\xbf\xf8\x45\x7c\x5a\xa1\x9c\x01\xe9\x5f\x58\x15\x7a\x1a\xcc\x57\xc1\x61\x89\xe1\xe8\x7e\xa2\x45\xb1\xc7\xc5\x13\xc5\x8f\x55\xb9\x77\x0b\x0d\xbe\xb4\xbd\x7b\x33\x84\x71\x87\x86\x0d\xae\x30\x8e\xd1\x12\x65\x14\xe3\x44\x74\xa1\xf0\x63\x35\x70\x2c\x3d\x0d\x40\x4a\x53\x55\xe2\xd6\xd3\xdb\x50\xeb\x39\x52\xaa\xf7\x33\x56\x67\x6c\x6e\x9b\xbd\x06\xaf\xee\xdc\x37\xa2\x6f\x40\xa3\x12\x14\x0c\x77\xa4\x12\xff\x2d\xd2\x5a\xd7\x23\xca\xdc\x3d\x0b\x27\x0e\x9a\x37\x6c\x05\xf9\x5e\xb3\xb2\x68\xbd\xfd\xae\x60\xb1\x57\xe4\xcf\xc0\x3a\x33\xd1\xda\x2a\x1f\xc0\xd7\x56\x61\xed\xa1\x67\xe8\x89\x28\xca\x2f\x28\x55\x36\x2f\x9f\x62\x3d\x64\xb6\x9e\xa8\xe0\x02\x56\xe7\xa9\xa8\xea\x32\xe3\x37\x16\xf7\x34\xe2\x5a\xa8\xbc\xe0\xe5\x46\x99\xa2\x85\xbb\x15\xbd\x14\xa3\xab\xcc\x43\x95\xe2\xe0\x7e\xab\xfa\xe4\x45\x2f\x6e\x19\x38\xdb\x43\xb8\x97\x1e\xe3\x7e\x5e\x62\x5c\xab\x7d\x02\xc5\x1e\x10\x55\xaf\x85\xf8\x24\x23\xef\x89\x78\xa9\x6f\xd2\x51\x21\x9f\x04\x7b\x7b\xbc\x81\xd6\xb1\xa3\x25\xb7\xbe\xf2\x46\x85\x45\x3f\xfe\xf6\x92\x29\x31\x6f\xd1\x66\xf0\x0f\xc4\xf3\x48\x13\xe1\x67\x3d\x55\x14\xd0\x62\x2d\x31\x6a\xbf\x25\x82\xad\xc7\xe4\xc7\xc2\x00\xa5\xbe\x68\x37\x20\x94\x72\x98\xa0\x03\x04\xae\x97\x5f\x2e\xc6\x5e\x13\x7c\xe0\x33\xae\x83\xd3\x1f\x22\x37\xeb\x39\xc5\xb5\x2f\x8a\x32\x7e\x0e\x8e\xf6\x5e\x7f\x0d\xf6\xa8\x9f\xbe\x17\xef\x6d\x98\x68\xdc\x60\x53\x90\xcd\x75\x53\x73\xb2\x6a\xdb\xe2\xf5\x8f\xe8\x52\xf4\x53\x0b\xb4\xe2\x2e\x90\xe6\x3d\xfc\xfe\x26\xb3\xcb\x76\x3a\xc8\x05\xdd\x4e\x34\x45\x67\x77\xb5\x6f\x73\x88\x51\x64\x1c\x93\x02\x43\xef\x27\x95\xb9\x48\xe5\x76\x5c\xc1\x87\xeb\x34\x28\x08\x3a\x65\x2c\x9f\xf5\x16\x5f\xe4\x1f\x3a\x8b\x3e\x0b\xc6\xa0\x4f\x93\xfa\xc8\x55\xcd\x81\xea\x5e\x1a\x21\xc0\xde\x5d\x71\xed\x09\x37\x88\xd5\x24\xdb\x89\x47\x41\x31\xb3\xe4\x35\x31\x56\xbf\xcc\xa2\xb7\x0b\xa4\x1a\x8a\x9f\xcb\x06\x85\xc7\x3e\x4f\xe9\x9a\x79\x77\x65\xba\x5f\x0f\x20\x6b\x6b\x7f\x88\xfd\x3c\x0c\x0a\x67\x37\x1b\x86\xe1\x26\x77\x6a\xe3\xdd\x10\x85\xd9\xd6\xf8\xf5\x12\xc2\xea\x44\x38\xa8\x4f\xa6\xae\x3f\xe1\xdf\x95\xbf\x03\xbf\xca\xac\x14\xff\x27\x32\xcb\xe5\x47\xd0\xcb\x56\x70\x45\xd5\x3d\x2a\xbb\xff\xa4\xfd\x36\x9f', 2)

# cleanup
del pyarmor_runtime

